@@ -1,8 +1,12 @@
+#[cfg(feature = "std")]
+use std::io::ErrorKind;
 use alloc::boxed::Box;
 use alloc::collections::BTreeMap;
 use alloc::vec;
 use alloc::vec::Vec;
 
+#[cfg(feature = "std")]
+use crate::interface::serial::SerialError;
 use crate::convert_packet::ConvertPacket;
 use crate::interface::*;
 use crate::packet::Packet;
@@ -103,6 +107,12 @@ impl<'a, I: Interface> Protocol<'a, I> {
                     }
                     Err(err) => match err {
                         InterfaceError::NoPacketReceived => break,
+                        #[cfg(feature = "std")]
+                        InterfaceError::SerialError(SerialError::ReadError(err)) => {
+                            if let ErrorKind::TimedOut = err.kind() {
+                                break;
+                            }
+                        },
                         _ => return Err(ProtocolError::InterfaceError(err)),
                     },
                 }
@@ -140,6 +150,12 @@ impl<'a, I: Interface> Protocol<'a, I> {
                     }
                     Err(err) => match err {
                         InterfaceError::NoPacketReceived => break,
+                        #[cfg(feature = "std")]
+                        InterfaceError::SerialError(SerialError::ReadError(err)) => {
+                            if let ErrorKind::TimedOut = err.kind() {
+                                break;
+                            }
+                        },
                         _ => return Err(ProtocolError::InterfaceError(err)),
                     },
                 }
